@echo off
rem REVERT-4.1.2-patch1.bat 1.0.1     UTF-8                       2016-08-24
rem -----1---------2---------3---------4---------5---------6---------7-------*
rem 
rem Licensed to the Apache Software Foundation (ASF) under one
rem or more contributor license agreements.  See the NOTICE file
rem distributed with this work for additional information
rem regarding copyright ownership.  The ASF licenses this file
rem to you under the Apache License, Version 2.0 (the
rem "License"); you may not use this file except in compliance
rem with the License.  You may obtain a copy of the License at
rem
rem  http://www.apache.org/licenses/LICENSE-2.0
rem
rem Unless required by applicable law or agreed to in writing,
rem software distributed under the License is distributed on an
rem "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
rem KIND, either express or implied.  See the License for the
rem specific language governing permissions and limitations
rem under the License.
rem
rem -----1---------2---------3---------4---------5---------6---------7-------*

rem ANNOUNCE THIS SCRIPT
TITLE APACHE OPENOFFICE 4.1.2-PATCH1 PROCEDURE
COLOR 71
rem   Soft white background with blue text
CLS
ECHO:
ECHO * 1.0.1 REVERT 4.1.2-PATCH1 FROM APACHE OPENOFFICE 4.1.2 ON WINDOWS

rem VERIFY SCRIPT IN SAME LOCATION (%~dp0) AS EXTRACTED ZIP PACKAGE
IF NOT EXIST "%~dp0LICENSE.txt" GOTO :FAIL1
IF NOT EXIST "%~dp0NOTICE.txt" GOTO :FAIL1
IF NOT EXIST "%~dp0README-4.1.2-patch1-Windows.txt" GOTO :FAIL1
IF NOT EXIST "%~dp0APPLY-4.1.2-patch1.bat" GOTO :FAIL1
IF NOT EXIST "%~dp0tl.dll.new" GOTO :FAIL1
IF NOT EXIST "%~dp0tl.dll.new.asc" GOTO :FAIL1
IF NOT EXIST "%~dp0tl.dll.old" GOTO :FAIL1
IF NOT EXIST "%~dp0tl.dll.old.asc" GOTO :FAIL1

rem REPORT APPARENT RESTART
IF NOT DEFINED AOOPATCH GOTO :LOCATE
ECHO:        A previous patch operation may have been interrupted.

:LOCATE
rem LOCATE X86 PROGRAM FILES
SET AOOPATCH=%ProgramFiles%
IF DEFINED ProgramFiles(x86) SET AOOPATCH=%ProgramFiles(x86)%

rem FIND APACHE OPENOFFICE 
SET AOOPATCH=%AOOPATCH%\OpenOffice 4\program
IF NOT EXIST "%AOOPATCH%\soffice.exe" GOTO :FAIL2
ECHO:        Found %AOOPATCH%
ECHO:        Please Wait. Checking files ...
IF EXIST "%AOOPATCH%\hwp.dll" GOTO :FAIL2

rem    OpenOffice 4.x.x without hwp.dll detected.  It is likely 4.1.2
rem    although it can be another where hwp.dll was deleted by the user.
rem    It could also be a post-4.1.2 version of OpenOffice 4.  The key
rem    is whether the 4.1.2-patch1 library is present.

rem VERIFY THAT TL.DLL EXISTS
IF NOT EXIST "%AOOPATCH%\tl.dll" GOTO :NODLL

rem SEE IF TL.DLL IS THE PATCHED FORM
FC /B "%AOOPATCH%\tl.dll" "%~dp0tl.dll.new" >NUL
IF NOT ERRORLEVEL 1 GOTO :PATCHED

rem OPENOFFICE IS NOT PATCHED 
ECHO:
ECHO:        THE 4.1.2-PATCH1 IS NOT PRESENT.
ECHO:
ECHO:        NO CHANGES WERE MADE.
GOTO :CLEAN

:PATCHED
ECHO:        Found 4.1.2-patch1 at tl.dll.
GOTO :REVERT

:NODLL
rem THERE IS NO TL.DLL.  IT IS EITHER UNNECESSARY OR THERE WAS A MISHAP.
ECHO:        File tl.dll is missing.

:REVERT
rem USE TL.DLL.OLD IF THERE IS ONE, ELSE SUPPLY THE 4.1.2 ONE
IF NOT EXIST "%AOOPATCH%\tl.dll.old" GOTO :RESETOLD
ECHO:        Found tl.dll.old to restore from.
GOTO :RESTORE

:RESETOLD
COPY /B "%~dp0tl.dll.old" "%AOOPATCH%\tl.dll.old" >NUL 2>&1
IF ERRORLEVEL 1 GOTO :FAIL3
rem     forcing a clean RESTORE as if there'd been an APPLY  
ECHO:        There is no tl.dll.old backup copy.  
ECHO:        Restoring with original 4.1.2 tl.dll.

:RESTORE
MOVE /Y "%AOOPATCH%\tl.dll.old" "%AOOPATCH%\tl.dll" >NUL 2>&1
IF ERRORLEVEL 1 GOTO :FAIL3

rem THE MOVE SUCCEEDED
ECHO:        The tl.dll library file is now restored.
ECHO:
ECHO:        REVERTING 4.1.2-PATCH1 HAS SUCCEEDED

:CLEAN
ECHO:
ECHO:        To apply the patch for any reason, use the procedure
ECHO:        APPLY-4.1.2-patch1.bat as described in the
ECHO:        README-4.1.2-patch1-Windows.txt file.   

:LEAVE
ECHO:
ECHO:
SET AOOPATCH=
PAUSE
EXIT /B 0


:FAIL1
ECHO:
ECHO * ***** THE REVERT SCRIPT IS NOT IN THE PROPER FOLDER LOCATION
ECHO *       REVERT-4.1.2-patch1.bat must be located in the folder 
ECHO *       apache-openoffice-4.1.2-patch1-Win_x86.zip is extracted to.
ECHO *       It is not designed to operate separately.
ECHO *
ECHO *       Follow the steps IN README-4.1.2-patch1-Windows.txt
ECHO *       to create the correct folder with this script included.

:BAIL
COLOR 74
rem   Soft White background and Red text
ECHO:
ECHO:
SET AOOPATCH=
PAUSE
EXIT /B 2

:FAIL2
ECHO:
ECHO * ***** APACHE OPENOFFICE 4.1.2 NOT FOUND
ECHO *       An eligible version of Apache OpenOffice is not detected in
ECHO *       the expected location on this Windows PC.
ECHO *     
ECHO *       NO CHANGES HAVE BEEN MADE.  
ECHO *       The APPLY procedure was not operated previously.  If a manual
ECHO *       procedure was applied instead, arrange to manually carry out the
ECHO *       reverse procedure in order to restore any earlier tl.dll.
GOTO :BAIL

:FAIL3
ECHO:
ECHO * ***** ADMINISTRATOR PRIVILEGE REQUIRED
ECHO *       This batch script, REVERT-4.1.2-patch1.bat, must be
ECHO *       initiated with the "Run as administrator" option if
ECHO *       available.  On Windows XP, run from an account having
ECHO *       administrative privileges.
ECHO *.
ECHO *       See README-4.1.2-patch1-Windows.txt file for 
ECHO *       further details.
ECHO *       
ECHO *       NO CHANGES HAVE BEEN MADE.
GOTO :BAIL

rem           *** end of REVERT-4.1.2-patch1.bat ***